@@ -7,7 +7,7 @@ import numpy as np
 from torch_geometric.utils.convert import from_networkx
 from bpemb import BPEmb
 from sentence_transformers import SentenceTransformer
-from Graph import Grapher
+from graphmanagerlib.Graph import Grapher
 
 bpemb_en = BPEmb(lang="en", dim=100)
 sent_model = SentenceTransformer('distilbert-base-nli-stsb-mean-tokens')
